@@ -1,6 +1,6 @@
 <?php
 /*
- * @version $Id: dropdownMassiveActionField.php 12409 2010-09-14 08:29:46Z moyo $
+ * @version $Id: dropdownMassiveActionField.php 13762 2011-01-28 15:09:20Z yllen $
  -------------------------------------------------------------------------
  GLPI - Gestionnaire Libre de Parc Informatique
  Copyright (C) 2003-2010 by the INDEPNET Development Team.
@@ -229,10 +229,12 @@ if (isset($_POST["itemtype"]) && isset($_POST["id_field"]) && $_POST["id_field"]
             break;
 
          default : // dropdown case
-            // Specific plugin Type case
             $plugdisplay=false;
-            if ($plug=isPluginItemType($_POST["itemtype"])) {
-               $plugdisplay=doOneHook($plug['plugin'],
+            // Specific plugin Type case
+            if (($plug=isPluginItemType($_POST["itemtype"]))
+                // Specific for plugin which add link to core object
+                || ($plug=isPluginItemType(getItemTypeForTable($search['table'])))) {
+               $plugdisplay = doOneHook($plug['plugin'],
                                        'MassiveActionsFieldsDisplay',
                                           array('itemtype'  => $_POST["itemtype"],
                                                 'options'     => $search));
