@@ -1,6 +1,6 @@
 <?php
 /*
- * @version $Id: softwarelicense.tabs.php 10412 2010-02-09 08:02:42Z moyo $
+ * @version $Id: softwarelicense.tabs.php 11396 2010-04-27 17:50:23Z moyo $
  -------------------------------------------------------------------------
  GLPI - Gestionnaire Libre de Parc Informatique
  Copyright (C) 2003-2010 by the INDEPNET Development Team.
@@ -33,46 +33,55 @@
 // Purpose of file:
 // ----------------------------------------------------------------------
 
-
-
-$NEEDED_ITEMS=array("computer","software","rulesengine","tracking","document","user","group","link","reservation","infocom","contract","enterprise","rule.softwarecategories");
-
 define('GLPI_ROOT', '..');
 include (GLPI_ROOT . "/inc/includes.php");
 header("Content-Type: text/html; charset=UTF-8");
 header_nocache();
 
-
-if (!isset($_POST['ID'])) {
-	exit();
+if (!isset($_POST['id'])) {
+   exit();
+}
+if (!isset($_REQUEST['glpi_tab'])) {
+   exit();
 }
 
-if(!isset($_POST["sort"])) $_POST["sort"] = "";
-if(!isset($_POST["order"])) $_POST["order"] = "";
-if(!isset($_POST["withtemplate"])) $_POST["withtemplate"] = "";
+if (!isset($_POST["sort"])) {
+   $_POST["sort"] = "";
+}
+if (!isset($_POST["order"])) {
+   $_POST["order"] = "";
+}
+if (!isset($_POST["withtemplate"])) {
+   $_POST["withtemplate"] = "";
+}
 
-	checkRight("software","r");
+checkRight("software","r");
 
-		switch($_POST['glpi_tab']){
-			case -1:
-				showInfocomForm($CFG_GLPI["root_doc"]."/front/infocom.form.php",SOFTWARELICENSE_TYPE,$_POST["ID"]);
-            showDocumentAssociated(SOFTWARELICENSE_TYPE,$_POST["ID"],$_POST["withtemplate"]);
-				displayPluginAction(SOFTWARELICENSE_TYPE,$_POST["ID"],$_POST['glpi_tab'],$_POST["withtemplate"]);
-				break;
-			case 4 :
-				showInfocomForm($CFG_GLPI["root_doc"]."/front/infocom.form.php",SOFTWARELICENSE_TYPE,$_POST["ID"]);
-				break;
-			case 5 :
-				showDocumentAssociated(SOFTWARELICENSE_TYPE,$_POST["ID"],$_POST["withtemplate"]);
-				break;
-			case 12 :
-				showHistory(SOFTWARELICENSE_TYPE,$_POST["ID"]);
-				break;
-			default :
-				if (!displayPluginAction(SOFTWARELICENSE_TYPE,$_POST["ID"],$_POST['glpi_tab'],$_POST["withtemplate"])){
-				}
-				break;
-		}
+$license = new SoftwareLicense();
+if ($_POST["id"]>0 && $license->can($_POST["id"],'r')) {
+   switch($_REQUEST['glpi_tab']) {
+      case -1 :
+         Infocom::showForItem($license);
+         Document::showAssociated($license);
+         Plugin::displayAction($license, $_REQUEST['glpi_tab']);
+         break;
+
+      case 4 :
+         Infocom::showForItem($license);
+         break;
+
+      case 5 :
+         Document::showAssociated($license);
+         break;
+
+      case 12 :
+         Log::showForItem($license);
+         break;
+
+      default :
+         Plugin::displayAction($license, $_REQUEST['glpi_tab']);
+   }
+}
+ajaxFooter();
 
-	ajaxFooter();
 ?>
