@@ -1,6 +1,6 @@
 <?php
 /*
- * @version $Id: contract.form.php 10411 2010-02-09 07:58:26Z moyo $
+ * @version $Id: contract.form.php 13461 2010-12-24 10:20:18Z remi $
  -------------------------------------------------------------------------
  GLPI - Gestionnaire Libre de Parc Informatique
  Copyright (C) 2003-2010 by the INDEPNET Development Team.
@@ -60,7 +60,7 @@ if (isset($_POST["add"])) {
    if ($contract->delete($_POST)) {
       Event::log($_POST["id"], "contracts", 4, "financial", $_SESSION["glpiname"]." ".$LANG['log'][22]);
    }
-   glpi_header($CFG_GLPI["root_doc"]."/front/contract.php");
+   $contract->redirectToList();
 
 } else if (isset($_POST["restore"])) {
    $contract->check($_POST['id'],'w');
@@ -68,7 +68,7 @@ if (isset($_POST["add"])) {
    if ($contract->restore($_POST)) {
       Event::log($_POST["id"], "contracts", 4, "financial", $_SESSION["glpiname"]." ".$LANG['log'][23]);
    }
-   glpi_header($CFG_GLPI["root_doc"]."/front/contract.php");
+   $contract->redirectToList();
 
 } else if (isset($_POST["purge"])) {
    $contract->check($_POST['id'],'w');
@@ -76,7 +76,7 @@ if (isset($_POST["add"])) {
    if ($contract->delete($_POST,1)) {
       Event::log($_POST["id"], "contracts", 4, "financial", $_SESSION["glpiname"]." ".$LANG['log'][24]);
    }
-   glpi_header($CFG_GLPI["root_doc"]."/front/contract.php");
+   $contract->redirectToList();
 
 } else if (isset($_POST["update"])) {
    $contract->check($_POST['id'],'w');
