@@ -1,6 +1,6 @@
 <?php
 /*
- * @version $Id: dropdown.common.form.php 13461 2010-12-24 10:20:18Z remi $
+ * @version $Id: dropdown.common.form.php 13725 2011-01-25 08:49:21Z moyo $
  -------------------------------------------------------------------------
  GLPI - Gestionnaire Libre de Parc Informatique
  Copyright (C) 2003-2010 by the INDEPNET Development Team.
@@ -114,7 +114,10 @@ if (isset($_POST["add"])) {
 
 } else {
    $dropdown->displayHeader();
-   $dropdown->showForm($_GET["id"]);
+   if (!isset($options)) {
+      $options = array();
+   }
+   $dropdown->showForm($_GET["id"],$options);
    commonFooter();
 }
 
