@@ -1,6 +1,6 @@
 <?php
 /*
- * @version $Id: entity.php 10412 2010-02-09 08:02:42Z moyo $
+ * @version $Id: entity.php 10411 2010-02-09 07:58:26Z moyo $
  -------------------------------------------------------------------------
  GLPI - Gestionnaire Libre de Parc Informatique
  Copyright (C) 2003-2010 by the INDEPNET Development Team.
@@ -34,23 +34,10 @@
 // ----------------------------------------------------------------------
 
 
-$NEEDED_ITEMS=array("entity","user","search");
 define('GLPI_ROOT', '..');
 include (GLPI_ROOT . "/inc/includes.php");
 
-checkRight("entity","r");
+$dropdown = new Entity();
+include (GLPI_ROOT . "/front/dropdown.common.php");
 
-commonHeader($LANG['Menu'][37],$_SERVER['PHP_SELF'],"admin","entity");
-
-$entity=new Entity();
-$entity->title();
-
-
-manageGetValuesInSearch(ENTITY_TYPE);
-
-searchForm(ENTITY_TYPE,$_GET);
-
-showList(ENTITY_TYPE,$_GET);
-
-commonFooter();
 ?>
