@@ -1,6 +1,6 @@
 <?php
 /*
- * @version $Id: group.form.php 11873 2010-07-07 12:43:59Z moyo $
+ * @version $Id: group.form.php 13461 2010-12-24 10:20:18Z remi $
  -------------------------------------------------------------------------
  GLPI - Gestionnaire Libre de Parc Informatique
  Copyright (C) 2003-2010 by the INDEPNET Development Team.
@@ -55,7 +55,7 @@ if (isset($_POST["add"])) {
    $group->check($_POST["id"],'w');
    $group->delete($_POST);
    Event::log($_POST["id"], "groups", 4, "setup", $_SESSION["glpiname"]." ".$LANG['log'][22]);
-   glpi_header($CFG_GLPI["root_doc"]."/front/group.php");
+   $group->redirectToList();
 
 } else if (isset($_POST["update"])) {
    $group->check($_POST["id"],'w');
