@@ -1,6 +1,6 @@
 <?php
 /*
- * @version $Id: helpdesk.faq.php 10412 2010-02-09 08:02:42Z moyo $
+ * @version $Id: helpdesk.faq.php 12838 2010-10-21 12:47:29Z moyo $
  -------------------------------------------------------------------------
  GLPI - Gestionnaire Libre de Parc Informatique
  Copyright (C) 2003-2010 by the INDEPNET Development Team.
@@ -34,56 +34,54 @@
 // ----------------------------------------------------------------------
 
 
-
-$NEEDED_ITEMS=array("user","document","knowbase");
-
 define('GLPI_ROOT', '..');
 include (GLPI_ROOT . "/inc/includes.php");
 
-
-
 // Redirect management
-if (isset($_GET["redirect"])){
-	manageRedirect($_GET["redirect"]);
+if (isset($_GET["redirect"])) {
+   manageRedirect($_GET["redirect"]);
 }
 
 //*******************
 // Affichage Module FAQ
 //******************
 
+$name = "";
+checkFaqAccess();
+if (getLoginUserID()) {
+   helpHeader($LANG['Menu'][20],$_SERVER['PHP_SELF'],$_SESSION["glpiname"]);
+} else {
+   $_SESSION["glpilanguage"] = $CFG_GLPI['language'];
+   // Anonymous FAQ
+   simpleHeader($LANG['Menu'][20],array($LANG['Menu'][20] => $_SERVER['PHP_SELF']));
+}
 
+if (!isset($_GET["start"])) {
+   $_GET["start"] = 0;
+}
+if (!isset($_GET["contains"])) {
+   $_GET["contains"] = "";
+}
+if (!isset($_GET["knowbaseitemcategories_id"])) {
+   $_GET["knowbaseitemcategories_id"] = 0;
+}
 
-	$name="";
-	checkFaqAccess();
-	if (isset($_SESSION["glpiID"])){
-		helpHeader($LANG['Menu'][20],$_SERVER['PHP_SELF'],$_SESSION["glpiname"]);
-	} else {
-		$_SESSION["glpilanguage"]=$CFG_GLPI['language'];
-		// Anonymous FAQ
-		simpleHeader($LANG['Menu'][20],array($LANG['Menu'][20]=>$_SERVER['PHP_SELF']));
-	}
-	
-	if(!isset($_GET["start"])) $_GET["start"] = 0;
-	if (!isset($_GET["contains"])) $_GET["contains"] = "";
-	if(!isset($_GET["parentID"])) $_GET["parentID"] = 0;
+if (isset($_GET["id"])) {
+   $kb = new KnowbaseItem;
+   if ($kb->getFromDB($_GET["id"])) {
+      $kb->showFull(false);
+   }
 
+} else {
+   KnowbaseItem::searchForm($_SERVER['PHP_SELF'],$_GET["contains"],$_GET["knowbaseitemcategories_id"],1);
+   KnowbaseItemCategory::showFirstLevel($_SERVER['PHP_SELF'],$_GET["knowbaseitemcategories_id"] ,1);
+   KnowbaseItem::showList($_SERVER['PHP_SELF'],$_GET["contains"],$_GET["start"],
+                  $_GET["knowbaseitemcategories_id"],1);
+   if (!$_GET["knowbaseitemcategories_id"] && strlen($_GET["contains"]) == 0) {
+      KnowbaseItem::showViewGlobal($_SERVER['PHP_SELF'],1) ;
+   }
+}
 
-	if (isset($_GET["ID"])){
+helpFooter();
 
-		if (ShowKbItemFull($_GET["ID"],0)){
-			showDocumentAssociated(KNOWBASE_TYPE,$_GET["ID"],3);
-		}
-
-	} else {
-		searchFormKnowbase($_SERVER['PHP_SELF'],$_GET["contains"],$_GET["parentID"],1);
-		showKbCategoriesFirstLevel($_SERVER['PHP_SELF'],$_GET["parentID"] ,1);
-		showKbItemList($_SERVER['PHP_SELF'],$_GET["contains"],$_GET["start"],$_GET["parentID"],1);
-		if (!$_GET["parentID"]&&!strlen($_GET["contains"])){
-			showKbViewGlobal($_SERVER['PHP_SELF'],1) ;
-		}
-		
-	}
-
-	helpFooter();
-
-?>
\ No newline at end of file
+?>
