@@ -1,6 +1,6 @@
 <?php
 /*
- * @version $Id: profile.form.php 10411 2010-02-09 07:58:26Z moyo $
+ * @version $Id: profile.form.php 13464 2010-12-24 10:56:14Z remi $
  -------------------------------------------------------------------------
  GLPI - Gestionnaire Libre de Parc Informatique
  Copyright (C) 2003-2010 by the INDEPNET Development Team.
@@ -55,7 +55,7 @@ if (isset($_POST["add"])) {
    $prof->check($_POST['id'],'w');
 
    $prof->delete($_POST);
-   glpi_header($CFG_GLPI["root_doc"]."/front/profile.php");
+   $prof->redirectToList();
 
 } else if (isset($_POST["update"]) || isset($_POST["interface"])) {
    $prof->check($_POST['id'],'w');
