@@ -1,6 +1,6 @@
 <?php
 /*
- * @version $Id: report.networking.php 10412 2010-02-09 08:02:42Z moyo $
+ * @version $Id: report.networking.php 10411 2010-02-09 07:58:26Z moyo $
  -------------------------------------------------------------------------
  GLPI - Gestionnaire Libre de Parc Informatique
  Copyright (C) 2003-2010 by the INDEPNET Development Team.
@@ -29,70 +29,55 @@
  */
 /*!
   \brief affiche les diffents choix de rapports reseaux
-
  */
 
-
 define('GLPI_ROOT', '..');
 include (GLPI_ROOT . "/inc/includes.php");
 
-
-
 checkRight("reports","r");
 
 commonHeader($LANG['Menu'][6],$_SERVER['PHP_SELF'],"utils","report");
 
 # Titre
 
-
-
-
 echo "<table class='tab_cadre' >";
-echo "<tr><th align='center' colspan='3' >".$LANG['reports'][33]."</th></tr>";
+echo "<tr><th colspan='3'>&nbsp;".$LANG['reports'][33]."&nbsp;</th></tr>";
 echo "</table><br>";
+
 // 3. Selection d'affichage pour generer la liste
 
 echo "<form name='form' method='post' action='report.location.list.php'>";
-echo "<table class='tab_cadre'  width='500'>";
-echo "<tr class='tab_bg_1'><td>".$LANG['reports'][39]."</td>";
+echo "<table class='tab_cadre' width='500'>";
+echo "<tr class='tab_bg_1'><td width='120'>".$LANG['reports'][39]."</td>";
 echo "<td>";
-dropdownValue("glpi_dropdown_locations","location",0,1,$_SESSION["glpiactive_entity"]);
-echo "</td><td align='center' width='120'>";
+Dropdown::show('Location', array('entity' => $_SESSION["glpiactive_entity"]));
+echo "</td><td class='center' width='120'>";
 echo "<input type='submit' value='".$LANG['reports'][15]."' class='submit'>";
 echo "</td></tr>";
-echo "</table>";
-echo "</form>";
-
+echo "</table></form>";
 
 echo "<form name='form2' method='post' action='report.switch.list.php'>";
 echo "<table class='tab_cadre' width='500'>";
-echo "<tr class='tab_bg_1'><td>".$LANG['reports'][41]."</td>";
+echo "<tr class='tab_bg_1'><td width='120'>".$LANG['reports'][41]."</td>";
 echo "<td>";
-dropdownValue("glpi_networking", "switch");
-echo "</td><td align='center' width='120'>";
+Dropdown::show('NetworkEquipment', array('name' => 'switch'));
+echo "</td><td class='center' width='120'>";
 echo "<input type='submit' value='".$LANG['reports'][15]."' class='submit'>";
 echo "</td></tr>";
-echo "</table>";
-echo "</form>";
+echo "</table></form>";
 
-
-if (countElementsInTableForMyEntities("glpi_dropdown_netpoint")>0){
-	echo "<form name='form3' method='post' action='report.netpoint.list.php'>";
-	echo "<table class='tab_cadre'  width='500'>";
-	echo "<tr class='tab_bg_1'><td>".$LANG['reports'][42]."</td>";
-	echo "<td>";
-	dropdownNetpoint("prise",0,-1,1,$_SESSION["glpiactive_entity"]);	
-	echo "</td><td align='center' width='120'>";
-	echo "<input type='submit' value='".$LANG['reports'][15]."' class='submit'>";
-	echo "</td></tr>";
-	echo "</table>";
-	echo "</form>";
+if (countElementsInTableForMyEntities("glpi_netpoints") > 0) {
+   echo "<form name='form3' method='post' action='report.netpoint.list.php'>";
+   echo "<table class='tab_cadre' width='500'>";
+   echo "<tr class='tab_bg_1'><td width='120'>".$LANG['reports'][42]."</td>";
+   echo "<td>";
+   Netpoint::dropdownNetpoint("prise",0,-1,1,$_SESSION["glpiactive_entity"]);
+   echo "</td><td class='center' width='120'>";
+   echo "<input type='submit' value='".$LANG['reports'][15]."' class='submit'>";
+   echo "</td></tr>";
+   echo "</table></form>";
 }
 
-
-
-
-
 commonFooter();
 
-?>
+?>
\ No newline at end of file
