@@ -1,6 +1,6 @@
 <?php
 /*
- * @version $Id: report.year.php 10491 2010-02-14 22:52:02Z moyo $
+ * @version $Id: report.year.php 10492 2010-02-14 23:00:52Z moyo $
  -------------------------------------------------------------------------
  GLPI - Gestionnaire Libre de Parc Informatique
  Copyright (C) 2003-2010 by the INDEPNET Development Team.
@@ -40,50 +40,42 @@ checkRight("reports","r");
 commonHeader($LANG['Menu'][6],$_SERVER['PHP_SELF'],"utils","report");
 
 
-
 # Titre
 
-
 echo "<form name='form' method='post' action='report.year.list.php'>";
 
-echo "<div align='center'>";
 echo "<table class='tab_cadre' >";
-echo "<tr><th align='center' colspan='2' ><big><b>".$LANG['reports'][58]."</b></big></th></tr>";
+echo "<tr><th colspan='2'><big>".$LANG['reports'][58]."</big></th></tr>";
 
 # 3. Selection d'affichage pour generer la liste
 
 echo "<tr class='tab_bg_2'>";
-echo "<td width='150'  align='center'>";
-echo "<p><b>".$LANG['reports'][12]."</b></p> ";
-echo "<p><select name='item_type[]' size='8'  multiple>";
+echo "<td width='150' class='center'>";
+echo "<p class='b'>".$LANG['reports'][12]."</p> ";
+echo "<p><select name='item_type[]' size='8' multiple>";
 echo "<option value='0' selected>".$LANG['common'][66]."</option>";
-echo "<option value='".COMPUTER_TYPE."'>".$LANG['Menu'][0]."</option>";
-echo "<option value='".PRINTER_TYPE."'>".$LANG['Menu'][2]."</option>";
-echo "<option value='".NETWORKING_TYPE."'>".$LANG['help'][26]."</option>";
-echo "<option value='".MONITOR_TYPE."'>".$LANG['Menu'][3]."</option>";
-echo "<option value='".PERIPHERAL_TYPE."'>".$LANG['Menu'][16]."</option>";
-echo "<option value='".SOFTWARELICENSE_TYPE."'>".$LANG['Menu'][4]." - ".$LANG['software'][11]."</option>";
-echo "<option value='".PHONE_TYPE."'>".$LANG['Menu'][34]."</option>";
+echo "<option value='Computer'>".$LANG['Menu'][0]."</option>";
+echo "<option value='Printer'>".$LANG['Menu'][2]."</option>";
+echo "<option value='NetworkEquipment'>".$LANG['help'][26]."</option>";
+echo "<option value='Monitor'>".$LANG['Menu'][3]."</option>";
+echo "<option value='Peripheral'>".$LANG['Menu'][16]."</option>";
+echo "<option value='SoftwareLicense'>".$LANG['Menu'][4]." - ".$LANG['software'][11]."</option>";
+echo "<option value='Phone'>".$LANG['Menu'][34]."</option>";
 echo "</select> </p></td>";
 
-echo "<td width='150' align='center'><p><b>".$LANG['reports'][13]."</b></p> ";
-echo "<p> <select name='annee[]'  size='8' multiple>";
-echo " <option value='toutes' selected>".$LANG['common'][66]."</option>";
+echo "<td width='150' class='center'><p class='b'>".$LANG['reports'][13]."</p> ";
+echo "<p><select name='annee[]' size='8' multiple>";
+echo "<option value='toutes' selected>".$LANG['common'][66]."</option>";
 $y = date("Y");
-for ($i=$y-10;$i<$y+10;$i++)
-{
-	echo " <option value='$i'>$i</option>";
+for ($i=$y-10 ; $i<$y+10 ; $i++) {
+   echo " <option value='$i'>$i</option>";
 }
 echo "</select></p></td></tr>";
 
-echo "<tr class='tab_bg_2'><td colspan='2'  align='center'><p><input type='submit' value='".$LANG['reports'][15]."' class='submit'></p></td></tr>";
-
-
-echo "</table>";
-echo "</div>";
-echo "</form>";
-
+echo "<tr class='tab_bg_2'><td colspan='2' class='center'>";
+echo "<input type='submit' value='".$LANG['reports'][15]."' class='submit'></td></tr>";
 
+echo "</table></form>";
 
 commonFooter();
 
