@@ -1,6 +1,6 @@
 <?php
 /*
- * @version $Id: rule.cache.php 10412 2010-02-09 08:02:42Z moyo $
+ * @version $Id: rule.cache.php 10769 2010-02-25 16:55:55Z walid $
  -------------------------------------------------------------------------
  GLPI - Gestionnaire Libre de Parc Informatique
  Copyright (C) 2003-2010 by the INDEPNET Development Team.
@@ -33,34 +33,31 @@
 // Purpose of file:
 // ----------------------------------------------------------------------
 
-
-if(!defined('GLPI_ROOT')){
-	define('GLPI_ROOT', '..');
-
-	$NEEDED_ITEMS=array("entity","rulesengine","ocsng");
-	include (GLPI_ROOT . "/inc/includes.php");
+if (!defined('GLPI_ROOT')) {
+   define('GLPI_ROOT', '..');
+   include (GLPI_ROOT . "/inc/includes.php");
 }
 
-if (!strpos($_SERVER['PHP_SELF'],"popup"))
-	commonHeader($LANG['rulesengine'][17],$_SERVER['PHP_SELF'],"admin","dictionnary","cache");
+if (!strpos($_SERVER['PHP_SELF'],"popup")) {
+   commonHeader($LANG['rulesengine'][17], $_SERVER['PHP_SELF'], "admin", "dictionnary", "cache");
+}
 
-if (isset($_GET["sub_type"]))	
-{
-	echo "<br>";
-	$rulecollection = getRuleCollectionClass($_GET["sub_type"]);
-	if (haveRight($rulecollection->right,"r"))
-	{
-		if (!isset($_GET["rule_id"]))
-			$rulecollection->showCacheStatusForRuleType();
-		else
-		{
-			$rule = $rulecollection->getRuleClass();
-			$rule->getRuleWithCriteriasAndActions($_GET["rule_id"],0,0);
-			$rule->showCacheStatusByRule($_SERVER["HTTP_REFERER"]);
-		}
-	}
+if (isset($_GET["sub_type"])) {
+   echo "<br>";
+   $rulecollection = RuleCollection::getClassByType($_GET["sub_type"]);
+   if (haveRight($rulecollection->right,"r")) {
+      if (!isset($_GET["rules_id"])) {
+         $rulecollection->showCacheStatusForRuleType();
+      } else {
+         $rule = new $_GET["sub_type"]();
+         $rule->getRuleWithCriteriasAndActions($_GET["rules_id"],0,0);
+         $rule->showCacheStatusByRule($_SERVER["HTTP_REFERER"]);
+      }
+   }
+}
+
+if (!strpos($_SERVER['PHP_SELF'],"popup")) {
+   commonFooter();
 }
 
-if (!strpos($_SERVER['PHP_SELF'],"popup"))
-	commonFooter();
 ?>
