@@ -1,6 +1,6 @@
 <?php
 /*
- * @version $Id: setup.templates.php 10412 2010-02-09 08:02:42Z moyo $
+ * @version $Id: setup.templates.php 11453 2010-05-18 06:18:50Z moyo $
  -------------------------------------------------------------------------
  GLPI - Gestionnaire Libre de Parc Informatique
  Copyright (C) 2003-2010 by the INDEPNET Development Team.
@@ -30,30 +30,26 @@
 
 // Based on:
 // IRMA, Information Resource-Management and Administration
-// Christian Bauer 
+// Christian Bauer
 // ----------------------------------------------------------------------
 // Original Author of file:
 // Purpose of file:
 // ----------------------------------------------------------------------
 
-
-
-$NEEDED_ITEMS=array("setup");
-
 define('GLPI_ROOT', '..');
 include (GLPI_ROOT . "/inc/includes.php");
 
-$type="inventory";
-if ($_GET["type"]==OCSNG_TYPE){
-	$type="config";
+if (isset($_GET["itemtype"])) {
+
+   $link=getItemTypeFormURL($_GET["itemtype"]);
+   
+   $item = str_replace(".form.php","",$link);
+   $item = str_replace("front/","",$item);
+   commonHeader($LANG['common'][12],$_SERVER['PHP_SELF'],"inventory",$item);
+   
+   listTemplates($_GET["itemtype"],$link,$_GET["add"]);
+   
+   commonFooter();
 }
-$item=str_replace(".form.php","",$INFOFORM_PAGES[$_GET["type"]]);
-$item=str_replace("front/","",$item);
-commonHeader($LANG['common'][12],$_SERVER['PHP_SELF'],$type,$item);
-
-listTemplates($_GET["type"],$CFG_GLPI["root_doc"]."/".$INFOFORM_PAGES[$_GET["type"]],$_GET["add"]);
-
-commonFooter();
-
 
 ?>
