@@ -1,6 +1,6 @@
 <?php
 /*
- * @version $Id: transfer.php 10412 2010-02-09 08:02:42Z moyo $
+ * @version $Id: transfer.php 10661 2010-02-19 18:11:54Z moyo $
  -------------------------------------------------------------------------
  GLPI - Gestionnaire Libre de Parc Informatique
  Copyright (C) 2003-2010 by the INDEPNET Development Team.
@@ -33,22 +33,15 @@
 // Purpose of file:
 // ----------------------------------------------------------------------
 
-$NEEDED_ITEMS=array("transfer","search");
 
 define('GLPI_ROOT', '..');
 include (GLPI_ROOT . "/inc/includes.php");
 
-// TODO Add transfer Right
-
 checkRight("transfer","r");
 
-commonHeader($LANG['transfer'][1],$_SERVER['PHP_SELF'],"admin","transfer");
+commonHeader($LANG['transfer'][1],'',"admin","transfer");
 
-manageGetValuesInSearch(TRANSFER_TYPE);
-
-searchForm(TRANSFER_TYPE,$_GET);
-
-showList(TRANSFER_TYPE,$_GET);
+Search::show('Transfer');
 
 commonFooter();
 
