@@ -1,6 +1,6 @@
 <?php
 /*
- * @version $Id: auth.class.php 12520 2010-09-26 16:18:45Z walid $
+ * @version $Id: auth.class.php 13674 2011-01-18 13:57:10Z moyo $
  -------------------------------------------------------------------------
  GLPI - Gestionnaire Libre de Parc Informatique
  Copyright (C) 2003-2010 by the INDEPNET Development Team.
@@ -103,7 +103,7 @@ class Auth {
 
       $result = $DB->query($query);
       if ($DB->numrows($result) == 0) {
-         $this->addToError($LANG['login'][14]);
+         $this->addToError($LANG['login'][12]);
          return 0;
 
       } else {
@@ -179,19 +179,18 @@ class Auth {
                                                                       'value'=>$login),
                                                 'condition'        => $ldap_method['condition']));
          $dn = $infos['dn'];
-         if (@ldap_bind($this->ldap_connection, $dn, $password)) {
-
+         if (!empty($dn) && @ldap_bind($this->ldap_connection, $dn, $password)) {
             //Hook to implement to restrict access by checking the ldap directory
             if (doHookFunction("restrict_ldap_auth", $dn)) {
                return $dn;
             } else {
-               $this->addToError($LANG['login'][16]);
+               $this->addToError($LANG['login'][11]);
                //Use is present by has no right to connect because of a plugin
                return false;
             }
 
          } else {
-            //User is present by password in incorrect
+            // Incorrect login
             $this->addToError($LANG['login'][12]);
             //Use is not present anymore in the directory!
             if ($dn == '') {
@@ -237,7 +236,7 @@ class Auth {
       $result = $DB->query($query);
 
       if (!$result) {
-         $this->addToError($LANG['login'][14]);
+         $this->addToError($LANG['login'][12]);
          return false;
       }
       if ($result) {
@@ -518,12 +517,11 @@ class Auth {
          if ($this->getAlternateAuthSystemsUserLogin($authtype)
              && !empty($this->user->fields['name'])) {
 
-            $user = $this->user->fields['name'];
             // Used for log when login process failed
-            $login_name = $user;
+            $login_name = $this->user->fields['name']; 
             $this->auth_succeded = true;
             $this->extauth       = 1;
-            $this->user_present  = $this->user->getFromDBbyName(addslashes($user));
+            $this->user_present  = $this->user->getFromDBbyName(addslashes($login_name));
             $this->user->fields['authtype'] = $authtype;
             // if LDAP enabled too, get user's infos from LDAP
             $this->user->fields["auths_id"] = $CFG_GLPI['authldaps_id_extra'];
@@ -544,17 +542,18 @@ class Auth {
                                                        array('basedn'      => $ldap_method["basedn"],
                                                              'login_field' => $ldap_method['login_field'],
                                                              'search_parameters' => $params,
-                                                             'user_params' => $user,
+                                                             'user_params' => array('method'=>AuthLDAP::IDENTIFIER_LOGIN,
+                                                                      'value'=>$login_name),
                                                              'condition'   => $ldap_method["condition"]));
                      if ($user_dn) {
-                        $this->user->getFromLDAP($ds, $ldap_method, $user_dn, $user);
+                        $this->user->getFromLDAP($ds, $ldap_method, $user_dn['dn'], $login_name);
                      }
                   }
                }
             }
 
             // Reset to secure it
-            $this->user->fields['name']       = $user;
+            $this->user->fields['name']       = $login_name;
             $this->user->fields["last_login"] = $_SESSION["glpi_currenttime"];
 
          } else {
@@ -562,10 +561,6 @@ class Auth {
          }
       }
 
-      if ($noauto) {
-         $_SESSION["noAUTO"] = 1;
-      }
-
       // If not already auth
       if (!$this->auth_succeded) {
          if (empty($login_name) || empty($login_password)) {
@@ -595,10 +590,10 @@ class Auth {
                //The user is not authenticated on the GLPI DB, but we need to get informations about him
                //to find out his authentication method
                $this->user->getFromDBbyName(addslashes($login_name));
-
                //If the user has already been logged, the method_auth and auths_id are already set
                //so we test this connection first
                switch ($this->user->fields["authtype"]) {
+                  case Auth::CAS :
                   case Auth::EXTERNAL :
                   case Auth::LDAP :
                      if (canUseLdap()) {
@@ -695,6 +690,9 @@ class Auth {
       }
 
       $this->initSession();
+      if ($noauto) {
+         $_SESSION["noAUTO"] = 1;
+      }
       return $this->auth_succeded;
    }
 
@@ -1026,4 +1024,4 @@ class Auth {
    }
 }
 
-?>
\ No newline at end of file
+?>
