@@ -1,6 +1,6 @@
 <?php
 /*
- * @version $Id: cartridgeitem.class.php 12277 2010-09-06 11:37:28Z yllen $
+ * @version $Id: cartridgeitem.class.php 14037 2011-03-07 09:06:57Z yllen $
  -------------------------------------------------------------------------
  GLPI - Gestionnaire Libre de Parc Informatique
  Copyright (C) 2003-2010 by the INDEPNET Development Team.
@@ -109,7 +109,7 @@ class CartridgeItem extends CommonDBTM {
 
       $ong[1]=$LANG['Menu'][21];
       if ($this->fields['id'] > 0) {
-         if (haveRight("contract","r") || haveRight("infocom","r")) {
+         if (haveRight("infocom","r")) {
             $ong[4]=$LANG['Menu'][26];
          }
          if (haveRight("document","r")) {
