@@ -1,6 +1,6 @@
 <?php
 /*
- * @version $Id: commondbtm.class.php 13661 2011-01-18 11:06:56Z moyo $
+ * @version $Id: commondbtm.class.php 13889 2011-02-15 21:45:27Z moyo $
  -------------------------------------------------------------------------
  GLPI - Gestionnaire Libre de Parc Informatique
  Copyright (C) 2003-2010 by the INDEPNET Development Team.
@@ -1378,7 +1378,7 @@ class CommonDBTM extends CommonGLPI {
       //if (get_class($this)=='Entity' && !$ID) {
          // Very special case ;)
       //} else
-      if ($params['withtemplate'] || $ID<=0) {
+      if ($params['withtemplate'] || $this->isNewID($ID)) {
          echo "<td class='tab_bg_2 center' colspan='".($params['colspan']*2)."'>";
          if ($ID<=0 || $params['withtemplate']==2){
             echo "<input type='submit' name='add' value=\"".$LANG['buttons'][8]."\" class='submit'>";
@@ -1519,28 +1519,32 @@ class CommonDBTM extends CommonGLPI {
       if (get_class($this)=='Entity') {
          // is recursive but cannot be change
       } else
-      if ($this->maybeRecursive() && isMultiEntitiesMode()) {
-         echo $LANG['entity'][9]."&nbsp;:&nbsp;";
-         if (!$this->can($ID,'recursive')) {
-            echo Dropdown::getYesNo($this->fields["is_recursive"]);
-            $comment=$LANG['common'][86];
-            $image="/pics/lock.png";
-         // CommonDBChild : entity data is get or copy from parent
-         } else if ( $this instanceof CommonDBChild) {
-            echo Dropdown::getYesNo($this->isRecursive());
-            $comment=$LANG['common'][91];
-            $image="/pics/lock.png";
-         } else if ( !$this->canUnrecurs()) {
-            echo Dropdown::getYesNo($this->fields["is_recursive"]);
-            $comment=$LANG['common'][84];
-            $image="/pics/lock.png";
-         } else {
-            Dropdown::showYesNo("is_recursive",$this->fields["is_recursive"]);
-            $comment=$LANG['common'][85];
-            $image="/pics/aide.png";
-         }
-         echo "&nbsp;";
-         showToolTip($comment);
+      if ($this->maybeRecursive()) {
+         if (isMultiEntitiesMode()) {
+            echo $LANG['entity'][9]."&nbsp;:&nbsp;";
+            if (!$this->can($ID,'recursive')) {
+               echo Dropdown::getYesNo($this->fields["is_recursive"]);
+               $comment=$LANG['common'][86];
+               $image="/pics/lock.png";
+            // CommonDBChild : entity data is get or copy from parent
+            } else if ( $this instanceof CommonDBChild) {
+               echo Dropdown::getYesNo($this->isRecursive());
+               $comment=$LANG['common'][91];
+               $image="/pics/lock.png";
+            } else if ( !$this->canUnrecurs()) {
+               echo Dropdown::getYesNo($this->fields["is_recursive"]);
+               $comment=$LANG['common'][84];
+               $image="/pics/lock.png";
+            } else {
+               Dropdown::showYesNo("is_recursive",$this->fields["is_recursive"]);
+               $comment=$LANG['common'][85];
+               $image="/pics/aide.png";
+            }
+            echo "&nbsp;";
+            showToolTip($comment);
+            } else {
+               echo "<input type='hidden' name='is_recursive' value='0'>";
+            }
       } else {
          echo "&nbsp;";
       }
