@@ -1,6 +1,6 @@
 <?php
 /*
- * @version $Id: computer_device.class.php 13564 2011-01-11 08:32:53Z moyo $
+ * @version $Id: computer_device.class.php 13830 2011-02-08 16:47:27Z moyo $
  -------------------------------------------------------------------------
  GLPI - Gestionnaire Libre de Parc Informatique
  Copyright (C) 2003-2010 by the INDEPNET Development Team.
@@ -497,7 +497,8 @@ class Computer_Device extends CommonDBTM {
             }
          }
       }
-      if ($this->fields['specificity'] == $this->input['specificity']) {
+      if (isset($this->fields['specificity']) 
+            && $this->fields['specificity'] == $this->input['specificity']) {
          // No change
          return false;
       }
