@@ -1,6 +1,6 @@
 <?php
 /*
- * @version $Id: config.class.php 12913 2010-10-27 16:47:31Z moyo $
+ * @version $Id: config.class.php 13546 2011-01-07 16:08:56Z yllen $
  -------------------------------------------------------------------------
  GLPI - Gestionnaire Libre de Parc Informatique
  Copyright (C) 2003-2010 by the INDEPNET Development Team.
@@ -294,7 +294,7 @@ class Config extends CommonDBTM {
       echo "</tr>";
 
       echo "<tr><th>&nbsp;</th>";
-      echo "<th>" . $LANG['common'][92] . "</th>";
+      echo "<th>" . $LANG['common'][18] . "</th>";
       echo "<th>" . $LANG['common'][34] . "</th>";
       echo "<th>" . $LANG['common'][35] . "</th>";
       echo "<th>" . $LANG['common'][15] . "</th>";
@@ -309,7 +309,7 @@ class Config extends CommonDBTM {
       foreach ($fields as $field) {
          echo "<td>";
          $fieldname = "is_".$field."_autoupdate";
-         Dropdown::showFromArray($fieldname,$values, array('name'=>$CFG_GLPI[$fieldname]));
+         Dropdown::showFromArray($fieldname, $values, array('value' => $CFG_GLPI[$fieldname]));
          echo "</td>";
       }
       echo "<td>";
@@ -325,7 +325,7 @@ class Config extends CommonDBTM {
       foreach ($fields as $field) {
          echo "<td>";
          $fieldname = "is_".$field."_autoclean";
-         Dropdown::showFromArray($fieldname,$values, array('name'=>$CFG_GLPI[$fieldname]));
+         Dropdown::showFromArray($fieldname, $values, array('value' => $CFG_GLPI[$fieldname]));
          echo "</td>";
       }
       echo "<td>";
@@ -829,7 +829,7 @@ class Config extends CommonDBTM {
       }
       echo "MySQL: $version (".$DB->dbuser."@".$DB->dbhost."/".$DB->dbdefault.")\n";
 
-      foreach ($CFG_GLPI["systeminformations_type"] as $type) {
+      foreach ($CFG_GLPI["systeminformations_types"] as $type) {
       	$tmp = new $type;
          $tmp->showSystemInformations($width);
       }
