@@ -1,6 +1,6 @@
 <?php
 /*
- * @version $Id: consumable.class.php 12947 2010-11-02 07:30:21Z moyo $
+ * @version $Id: consumable.class.php 13913 2011-02-17 19:03:17Z yllen $
  -------------------------------------------------------------------------
  GLPI - Gestionnaire Libre de Parc Informatique
  Copyright (C) 2003-2010 by the INDEPNET Development Team.
@@ -456,7 +456,7 @@ class Consumable extends CommonDBTM {
 
             if ($show_old) {
                echo "<td class='center'>";
-               echo formatUserName($data["USERID"], $data["REALNAME"], $data["REALNAME"], $data["FIRSTNAME"]);
+               echo formatUserName($data["USERID"], $data["USERNAME"], $data["REALNAME"], $data["FIRSTNAME"]);
                echo "</td>";
             }
             echo "<td class='center'>";
