@@ -1,6 +1,6 @@
 <?php
 /*
- * @version $Id: document.class.php 13034 2010-11-12 09:34:42Z yllen $
+ * @version $Id: document.class.php 13909 2011-02-17 13:12:08Z yllen $
  -------------------------------------------------------------------------
  GLPI - Gestionnaire Libre de Parc Informatique
  Copyright (C) 2003-2010 by the INDEPNET Development Team.
@@ -54,27 +54,31 @@ class Document extends CommonDBTM {
 
    function canCreate() {
 
-      if ($_SESSION["glpiactiveprofile"]["interface"] == 'helpdesk') {
-         return true;
-      }
+      // Have right to add document OR ticket followup
+      return haveRight('document', 'w') || haveRight('add_followups', '1');
+   }
+
+
+   function canUpdate() {
+
       return haveRight('document', 'w');
    }
 
 
    function canCreateItem() {
-      //
-      if ($_SESSION["glpiactiveprofile"]["interface"] == 'helpdesk'
-          && isset($this->fields['itemtype'])
-          && $this->fields['itemtype']== 'Ticket'
-          && isset($this->fields['items_id'])
-          && $this->fields['items_id']>0) {
 
+      // From Ticket Document Tab => check right to add followup.
+      if (isset($this->fields['tickets_id'])
+          && $this->fields['tickets_id']>0) {
          $ticket = new Ticket();
-         if ($ticket->getFromDB($this->fields['items_id'])) {
+         if ($ticket->getFromDB($this->fields['tickets_id'])) {
             return $ticket->canAddFollowups();
          }
       }
-      return parent::canCreateItem();
+      if (haveRight('document', 'w')) {
+         return parent::canCreateItem();
+      }
+      return false;
    }
 
 
@@ -1227,6 +1231,9 @@ class Document extends CommonDBTM {
             echo "<input type='hidden' name='is_recursive' value='".($is_recursive?1:0)."'>";
             echo "<input type='hidden' name='itemtype' value='".$item->getType()."'>";
             echo "<input type='hidden' name='items_id' value='$ID'>";
+            if ($item->getType()=='Ticket') {
+               echo "<input type='hidden' name='tickets_id' value='$ID'>";
+            }
             echo "<input type='file' name='filename' size='25'>&nbsp;";
             echo "(".self::getMaxUploadSize().")&nbsp;";
             echo "<input type='submit' name='add' value=\"".$LANG['buttons'][8]."\" class='submit'></td>";
