@@ -1,6 +1,6 @@
 <?php
 /*
- * @version $Id: includes.php 10919 2010-03-08 18:16:28Z moyo $
+ * @version $Id: includes.php 13710 2011-01-24 08:56:31Z remi $
  -------------------------------------------------------------------------
  GLPI - Gestionnaire Libre de Parc Informatique
  Copyright (C) 2003-2010 by the INDEPNET Development Team.
@@ -172,6 +172,8 @@ if (!isset($AJAX_INCLUDE) && !isset($PLUGINS_INCLUDED)) {
             Plugin::load($name);
          }
       }
+      // For plugins which require action after all plugin init
+      doHook("post_init");
    }
 }
 
