@@ -1,7 +1,7 @@
 <?php
 
 /*
- * @version $Id: log.class.php 11964 2010-07-27 13:47:24Z moyo $
+ * @version $Id: log.class.php 13623 2011-01-14 12:47:22Z remi $
  -------------------------------------------------------------------------
  GLPI - Gestionnaire Libre de Parc Informatique
  Copyright (C) 2003-2010 by the INDEPNET Development Team.
@@ -229,7 +229,7 @@ class Log extends CommonDBTM {
                 `glpi_logs` (`items_id`, `itemtype`, `itemtype_link`, `linked_action`, `user_name`,
                              `date_mod`, `id_search_option`, `old_value`, `new_value`)
                 VALUES ('$items_id', '$itemtype', '$itemtype_link', '$linked_action','".
-                        addslashes($username)."', '$date_mod', '$id_search_option', 
+                        addslashes($username)."', '$date_mod', '$id_search_option',
                         '$old_value', '$new_value')";
 
       if ($DB->query($query)) {
@@ -297,10 +297,11 @@ class Log extends CommonDBTM {
     * @param $item CommonDBTM object
     * @param $start interger first line to retrieve
     * @param $limit interfer max number of line to retrive (0 for all)
+    * @param $sqlfilter string to add an SQL filter
     *
     * @return array of localized log entry (TEXT only, no HTML)
     */
-   static function getHistoryData(CommonDBTM $item, $start=0, $limit=0) {
+   static function getHistoryData(CommonDBTM $item, $start=0, $limit=0, $sqlfilter='') {
       global $DB, $LANG;
 
       $itemtype = $item->getType();
@@ -311,8 +312,11 @@ class Log extends CommonDBTM {
       $query="SELECT *
               FROM `glpi_logs`
               WHERE `items_id`='".$items_id."'
-                    AND `itemtype`='".$itemtype."'
-              ORDER BY `id` DESC";
+                    AND `itemtype`='".$itemtype."' ";
+      if ($sqlfilter) {
+         $query .= "AND ($sqlfilter) ";
+      }
+      $query .= "ORDER BY `id` DESC";
       if ($limit) {
          $query .= " LIMIT ".intval($start)."," . intval($limit);
       }
