@@ -1,6 +1,6 @@
 <?php
 /*
- * @version $Id: notificationmail.class.php 11593 2010-06-09 22:54:39Z walid $
+ * @version $Id: notificationmail.class.php 13615 2011-01-12 14:00:02Z moyo $
  -------------------------------------------------------------------------
  GLPI - Gestionnaire Libre de Parc Informatique
  Copyright (C) 2003-2010 by the INDEPNET Development Team.
@@ -158,6 +158,7 @@ class NotificationMail extends phpmailer implements NotificationInterface {
       global $CFG_GLPI,$LANG;
 
       $mmail= new NotificationMail;
+      $mmail->AddCustomHeader("Auto-Submitted: auto-generated");
       $mmail->From = $CFG_GLPI["admin_email"];
       $mmail->FromName = $CFG_GLPI["admin_email"];
       $mmail->AddAddress($CFG_GLPI["admin_email"], "GLPI");
@@ -200,6 +201,8 @@ class NotificationMail extends phpmailer implements NotificationInterface {
       global $LANG;
 
       $mmail = new NotificationMail();
+      $mmail->AddCustomHeader("Auto-Submitted: auto-generated");
+
       $mmail->From = $options['from'];
       if ($options['replyto']) {
          $mmail->AddReplyTo($options['replyto'], '');
@@ -221,7 +224,7 @@ class NotificationMail extends phpmailer implements NotificationInterface {
 
       if (!$mmail->Send()) {
          $senderror = true;
-         addMessageAfterRedirect($messageerror."<br>".$mmail->ErrorInfo);
+         addMessageAfterRedirect($messageerror."<br>".$mmail->ErrorInfo,true);
       } else {
          logInFile("mail",$LANG['tracking'][38]." ".$options['to'].": ".$options['subject']."\n");
       }
