@@ -1,6 +1,6 @@
 <?php
 /*
- * @version $Id: notificationtarget.class.php 13597 2011-01-11 16:06:34Z moyo $
+ * @version $Id: notificationtarget.class.php 13756 2011-01-28 09:27:51Z remi $
  -------------------------------------------------------------------------
  GLPI - Gestionnaire Libre de Parc Informatique
  Copyright (C) 2003-2010 by the INDEPNET Development Team.
@@ -400,6 +400,22 @@ class NotificationTarget extends CommonDBChild {
          $new_lang = trim($data['language']);
       }
 
+      if (isset($data['id'])) {
+         $user = new User();
+         if (!$user->getFromDB($data['id'])
+             || $user->getField('is_deleted')==1
+             || $user->getField('is_active')==0) {
+            // unknown, deleted or disabled user
+            return false;
+         }
+         $filt = getEntitiesRestrictRequest('AND', 'glpi_profiles_users', '', $this->getEntity(), true);
+         $prof = $user->getUserProfiles($data['id'], $filt);
+         if (!count($prof)) {
+            // No right on the entity of the object
+            return false;
+         }
+      }
+
       $notificationoption = $this->addAdditionnalUserInfo($data);
       if (!empty($new_mail)) {
          if (NotificationMail::isUserAddressValid($new_mail) && !isset($this->target[$new_mail])) {
