@@ -1,6 +1,6 @@
 <?php
 /*
- * @version $Id: notificationtargetticket.class.php 13245 2010-12-07 14:32:50Z yllen $
+ * @version $Id: notificationtargetticket.class.php 13778 2011-02-03 07:54:58Z moyo $
  -------------------------------------------------------------------------
  GLPI - Gestionnaire Libre de Parc Informatique
  Copyright (C) 2003-2010 by the INDEPNET Development Team.
@@ -544,6 +544,8 @@ class NotificationTargetTicket extends NotificationTarget {
          }
          $this->datas['##ticket.storestatus##'] = $this->obj->getField('status');
          $this->datas['##ticket.status##']      = Ticket::getStatus($this->obj->getField('status'));
+         $this->datas['##ticket.globalvalidation##']
+                           = TicketValidation::getStatus($this->obj->getField('global_validation'));
          $this->datas['##ticket.requesttype##'] = Dropdown::getDropdownName('glpi_requesttypes',
                                                             $this->obj->getField('requesttypes_id'));
 
@@ -732,7 +734,7 @@ class NotificationTargetTicket extends NotificationTarget {
          if (!isset($options['additionnaloption']) || !$options['additionnaloption']) {
             $restrict .= " AND `is_private` = '0'";
          }
-         $restrict .= " ORDER BY `date` DESC";
+         $restrict .= " ORDER BY `date` DESC, `id` ASC";
 
          //Task infos
          $tasks = getAllDatasFromTable('glpi_tickettasks',$restrict);
@@ -785,7 +787,7 @@ class NotificationTargetTicket extends NotificationTarget {
          if (isset($options['validation_id']) && $options['validation_id']) {
             $restrict .= " AND `glpi_ticketvalidations`.`id` = '".$options['validation_id']."'";
          }
-         $restrict .= " ORDER BY `submission_date` DESC";
+         $restrict .= " ORDER BY `submission_date` DESC, `id` ASC";
          $validations = getAllDatasFromTable('glpi_ticketvalidations',$restrict);
 
          foreach ($validations as $validation) {
@@ -841,6 +843,8 @@ class NotificationTargetTicket extends NotificationTarget {
 
             $tmp['##ticket.title##']        = $ticket['name'];
             $tmp['##ticket.status##']       = Ticket::getStatus($ticket['status']);
+            $tmp['##ticket.globalvalidation##']
+                                            = TicketValidation::getStatus($ticket['global_validation']);
             $tmp['##ticket.requesttype##']  = Dropdown::getDropdownName('glpi_requesttypes',
                                                                         $ticket['requesttypes_id']);
 
