@@ -1,6 +1,6 @@
 <?php
 /*
- * @version $Id: planning.class.php 13247 2010-12-07 14:59:25Z moyo $
+ * @version $Id: planning.class.php 13820 2011-02-07 18:19:30Z moyo $
  -------------------------------------------------------------------------
  GLPI - Gestionnaire Libre de Parc Informatique
  Copyright (C) 2003-2010 by the INDEPNET Development Team.
@@ -600,7 +600,7 @@ class Planning {
       ksort($interv);
 
       echo "<table class='tab_cadrehov'><tr><th>";
-      echo "<a href='".$CFG_GLPI["root_doc"]."/front/planning.php'>".$LANG['planning'][15]."</a>";
+      echo "<a href='".$CFG_GLPI["root_doc"]."/front/planning.php?uID=$who'>".$LANG['planning'][15]."</a>";
       echo "</th></tr>";
       $type='';
       if (count($interv)>0) {
@@ -680,8 +680,8 @@ class Planning {
       if (count($interv)>0) {
          foreach ($interv as $key => $val) {
             $vevent = new vevent(); //initiate EVENT
-            if (isset($val["tickets_id"])) {
-               $vevent->setProperty("uid","Job#".$val["tickets_id"]);
+            if (isset($val["tickettasks_id"])) {
+               $vevent->setProperty("uid","Job#".$val["tickettasks_id"]);
             } else if (isset($val["reminders_id"])) {
                $vevent->setProperty("uid","Event#".$val["reminders_id"]);
             } else if (isset($val['planningID'])) { // Specify the ID (for plugins)
