@@ -1,6 +1,6 @@
 <?php
 /*
- * @version $Id: tickettask.class.php 12343 2010-09-09 06:56:39Z remi $
+ * @version $Id: tickettask.class.php 13535 2011-01-07 12:50:44Z moyo $
  -------------------------------------------------------------------------
  GLPI - Gestionnaire Libre de Parc Informatique
  Copyright (C) 2003-2010 by the INDEPNET Development Team.
@@ -248,14 +248,7 @@ class TicketTask  extends CommonDBTM {
 //      $input["_isadmin"] = haveRight("global_add_tasks","1");
       $input["_job"] = new Ticket;
 
-      if ($input["_job"]->getFromDB($input["tickets_id"])) {
-         // Security to add unusers_idized followups
-         if (!isset($input['_do_not_check_users_id'])
-             && $input["_job"]->fields["users_id"]!=getLoginUserID()
-             && !$input["_job"]->canAddFollowups()) {
-            return false;
-         }
-      } else {
+      if (!$input["_job"]->getFromDB($input["tickets_id"])) {
          return false;
       }
 
@@ -309,6 +302,13 @@ class TicketTask  extends CommonDBTM {
    function post_addItem() {
       global $CFG_GLPI;
 
+
+      $donotif = $CFG_GLPI["use_mailing"];
+
+      if (isset($this->input["_no_notif"]) && $this->input["_no_notif"]) {
+         $donotif = false;
+      }
+
       $this->input["_job"]->updateDateMod($this->input["tickets_id"]);
 
       if (isset($this->input["realtime"]) && $this->input["realtime"]>0) {
@@ -355,10 +355,7 @@ class TicketTask  extends CommonDBTM {
          $this->input["_job"]->updateInDB($updates);
       }
 */
-      if ($CFG_GLPI["use_mailing"]) {
-         if ($this->input["_close"]) {
-            $this->input["_type"] = "finish";
-         }
+      if ($donotif) {
          $options = array('task_id' => $this->fields["id"]);
          NotificationEvent::raiseEvent('add_task',$this->input["_job"],$options);
       }
@@ -544,7 +541,7 @@ class TicketTask  extends CommonDBTM {
       echo "<td>".$LANG['job'][31]."&nbsp;:</td><td>";
       $hour = floor($this->fields["realtime"]);
       $minute = round(($this->fields["realtime"]-$hour)*60,0);
-      Dropdown::showInteger('hour',$hour,0,100);
+      Dropdown::showInteger('hour',$hour,0,100,1,array($hour));
       echo "&nbsp;".$LANG['job'][21]."&nbsp;&nbsp;";
       Dropdown::showInteger('minute',$minute,0,59);
       echo "&nbsp;".$LANG['job'][22];
@@ -639,6 +636,49 @@ class TicketTask  extends CommonDBTM {
       }
    }
 
+   function getSearchOptions() {
+      global $LANG;
+
+      $tab = array();
+      $tab['common'] = $LANG['job'][9];
+
+      $tab[1]['table']        = $this->getTable();
+      $tab[1]['field']        = 'content';
+      $tab[1]['linkfield']    = '';
+      $tab[1]['name']         = $LANG['job'][7]." - ".$LANG['joblist'][6];
+
+      $tab[2]['table']        = 'glpi_taskcategories';
+      $tab[2]['field']        = 'name';
+      $tab[2]['linkfield']    = 'taskcategories_id';
+      $tab[2]['name']         = $LANG['job'][7]." - ".$LANG['common'][36];
+      $tab[2]['forcegroupby'] = true;
+
+      $tab[3]['table']        = $this->getTable();
+      $tab[3]['field']        = 'date';
+      $tab[3]['linkfield']    = '';
+      $tab[3]['name']         = $LANG['common'][26];
+      $tab[3]['datatype']     = 'datetime';
+
+      $tab[4]['table']        = $this->getTable();
+      $tab[4]['field']        = 'is_private';
+      $tab[4]['linkfield']    = '';
+      $tab[4]['name']         = $LANG['job'][9]. " ".$LANG['common'][77];
+      $tab[4]['datatype']     = 'bool';
+
+      $tab[5]['table']        = 'glpi_users';
+      $tab[5]['field']        = 'name';
+      $tab[5]['linkfield']    = 'users_id';
+      $tab[5]['name']         = $LANG['financial'][43];
+
+      $tab[6]['table']     = $this->getTable();
+      $tab[6]['field']     = 'realtime';
+      $tab[6]['linkfield'] = 'realtime';
+      $tab[6]['name']      = $LANG['job'][20];
+      $tab[6]['datatype']  = 'realtime';
+
+      return $tab;
+   }
+
    /**
     * Form to update a followup to a ticket
     *
