@@ -2,7 +2,7 @@
 
 
 /*
- * @version $Id: user.class.php 13541 2011-01-07 14:46:55Z moyo $
+ * @version $Id: user.class.php 13756 2011-01-28 09:27:51Z remi $
  -------------------------------------------------------------------------
  GLPI - Gestionnaire Libre de Parc Informatique
  Copyright (C) 2003-2010 by the INDEPNET Development Team.
@@ -1063,19 +1063,20 @@ class User extends CommonDBTM {
 
 
    /**
-    * Get user profiles (no entity association)
+    * Get user profiles (no entity association, use sqlfilter if needed)
     *
     *@param $ID Integer : Id of the user
+    *@param $sqlfilter String : additional filter (must start with AND)
     *
     *@return array of the IDs of the profiles
     **/
-   function getUserProfiles($ID) {
+   function getUserProfiles($ID, $sqlfilter='') {
       global $DB;
 
       $prof = array();
       $query = "SELECT DISTINCT `glpi_profiles_users`.`profiles_id`
                 FROM `glpi_profiles_users`
-                WHERE `glpi_profiles_users`.`users_id` = '$ID'";
+                WHERE `glpi_profiles_users`.`users_id` = '$ID' " . $sqlfilter;
       $result = $DB->query($query);
 
       if ($DB->numrows($result) > 0) {
