@@ -1,3 +1,9 @@
+/*!
+ * Ext JS Library 3.3.0
+ * Copyright(c) 2006-2010 Ext JS, Inc.
+ * licensing@extjs.com
+ * http://www.extjs.com/license
+ */
 /**
  * List compiled by mystix on the extjs.com forums.
  * Thank you Mystix!
@@ -8,6 +14,10 @@
 
 Ext.UpdateManager.defaults.indicatorText = '<div class="loading-indicator">Loading...</div>';
 
+if(Ext.data.Types){
+    Ext.data.Types.stripRe = /[\$,%]/g;
+}
+
 if(Ext.DataView){
   Ext.DataView.prototype.emptyText = "";
 }
