@@ -1,6 +1,6 @@
 <?php
 /*
- * @version $Id: fr_FR.php 13658 2011-01-18 10:58:45Z moyo $
+ * @version $Id: fr_FR.php 13713 2011-01-24 09:53:28Z yllen $
  -------------------------------------------------------------------------
  GLPI - Gestionnaire Libre de Parc Informatique
  Copyright (C) 2003-2010 by the INDEPNET Development Team.
@@ -1366,6 +1366,7 @@ $LANG['ocsng'][50]="IP(s) verrouillée(s)";
 $LANG['ocsng'][52]="Logiciel(s) verrouillé(s)";
 $LANG['ocsng'][54]="Logiciel mis dans la corbeille par la synchro OCSNG";
 $LANG['ocsng'][55]="Volume(s) verrouillé(s)";
+$LANG['ocsng'][56]="Composant(s) verrouillé(s)";
 $LANG['ocsng'][57]="Interface OCSNG";
 
 $LANG['pager'][1]="à";
@@ -2119,6 +2120,7 @@ $LANG['validation'][19]="Validation acceptée";
 $LANG['validation'][20]="Validation refusée";
 $LANG['validation'][21]="Valideur";
 $LANG['validation'][23]="L'utilisateur choisi n'a pas d'adresse email renseignée. La demande a été créée mais l'envoi de l'email a échoué.";
+$LANG['validation'][25] = "Statut global de la validation";
 $LANG['validation'][26]="Demande de validation";
 $LANG['validation'][27]="Une demande de validation a été soumise";
 $LANG['validation'][28]="Statut de la demande de validation";
