@@ -1211,6 +1211,7 @@ $LANG['ocsng'][50]="IPs bloqueadas";
 $LANG['ocsng'][52]="Software bloqueado"; 
 $LANG['ocsng'][54]="Software deleted by OCSNG synchronization"; 
 $LANG['ocsng'][55]="Volume(s) bloqueado(s)"; 
+$LANG['ocsng'][56]="Locked component(s)"; 
 $LANG['ocsng'][57]="OCSNG Interface"; 
 
 $LANG['pager'][1]="ata"; 
@@ -1937,6 +1938,7 @@ $LANG['validation'][19]="Approval granted";
 $LANG['validation'][20]="Approval denied"; 
 $LANG['validation'][21]="Approver"; 
 $LANG['validation'][23]="The selected user has no valid emailaddress. The request has been created, without email confirmation."; 
+$LANG['validation'][25]="Global validation status"; 
 $LANG['validation'][26]="Approval request"; 
 $LANG['validation'][27]="An approval request has been submitted"; 
 $LANG['validation'][28]="Status of the Approval request"; 
