@@ -1211,6 +1211,7 @@ $LANG['ocsng'][50]="Zárolt IP-k";
 $LANG['ocsng'][52]="Zárolt szoftver(ek)"; 
 $LANG['ocsng'][54]="OCS szinkron törölte a szoftvert"; 
 $LANG['ocsng'][55]="Zárolt kötet(ek)"; 
+$LANG['ocsng'][56]="Locked component(s)"; 
 $LANG['ocsng'][57]="OCSNG interfész"; 
 
 $LANG['pager'][1]="vége"; 
@@ -1937,6 +1938,7 @@ $LANG['validation'][19]="Érvényesítés elfogadva";
 $LANG['validation'][20]="Érvényesítés megtagadva"; 
 $LANG['validation'][21]="Érvényesítő felhasználó"; 
 $LANG['validation'][23]="A kiválasztott felhasználónak nincs e-mail címe. A kérelem létrejött, de levelet nem sikerült küldeni."; 
+$LANG['validation'][25]="Global validation status"; 
 $LANG['validation'][26]="Érvényesítési kérelem"; 
 $LANG['validation'][27]="Érvényesítési kérelem elküldve"; 
 $LANG['validation'][28]="Érvényesítési kérelem állapota"; 
