@@ -1211,6 +1211,7 @@ $LANG['ocsng'][50]="Zaklenjen IP";
 $LANG['ocsng'][52]="Zaklenjena programska oprema"; 
 $LANG['ocsng'][54]="Software deleted by OCSNG synchronization"; 
 $LANG['ocsng'][55]="Nosilci zaklenjeni"; 
+$LANG['ocsng'][56]="Locked component(s)"; 
 $LANG['ocsng'][57]="OCSNG Interface"; 
 
 $LANG['pager'][1]="do"; 
@@ -1937,6 +1938,7 @@ $LANG['validation'][19]="Uzakonitev sprejeta";
 $LANG['validation'][20]="Uzakonitev zavrnjena"; 
 $LANG['validation'][21]="Uzakonitev, potrditev uporabnika"; 
 $LANG['validation'][23]="Izbrani uporabnik nima veljavnega e-poštnega naslova. Prošnja se je skreirala, toda ni bila poslana na noben e-poštni naslov."; 
+$LANG['validation'][25]="Global validation status"; 
 $LANG['validation'][26]="Prošnja za uzakonitev"; 
 $LANG['validation'][27]="Prošnja za vrednotenje je bila predložena"; 
 $LANG['validation'][28]="Stanje prošnje za uzakonitev"; 
