@@ -1211,6 +1211,7 @@ $LANG['ocsng'][50]="固定IP";
 $LANG['ocsng'][52]="锁软件"; 
 $LANG['ocsng'][54]="软件被OCSNG同步删除"; 
 $LANG['ocsng'][55]="卷 锁定"; 
+$LANG['ocsng'][56]="Locked component(s)"; 
 $LANG['ocsng'][57]="OCSNG 界面"; 
 
 $LANG['pager'][1]="到"; 
@@ -1937,6 +1938,7 @@ $LANG['validation'][19]="获批准";
 $LANG['validation'][20]="拒绝批准"; 
 $LANG['validation'][21]="验证程序"; 
 $LANG['validation'][23]="该被选用户没有有效邮件地址。该请求已经被创造，没有邮件确认。"; 
+$LANG['validation'][25]="Global validation status"; 
 $LANG['validation'][26]="批准请求"; 
 $LANG['validation'][27]="一个验证请求已经被提交"; 
 $LANG['validation'][28]="审批要求的状态"; 
