@@ -1,7 +1,7 @@
 <?php
 
 /*
- * @version $Id: logout.php 12124 2010-08-13 09:17:47Z moyo $
+ * @version $Id: logout.php 13477 2011-01-04 08:10:25Z moyo $
  -------------------------------------------------------------------------
  GLPI - Gestionnaire Libre de Parc Informatique
  Copyright (C) 2003-2010 by the INDEPNET Development Team.
@@ -45,11 +45,11 @@ if (!isset($_SESSION["noAUTO"])
     && $_SESSION["glpiauthtype"]==Auth::CAS) {
 
    include (GLPI_ROOT . "/lib/phpcas/CAS.php");
-   $cas=new phpCAS();
-   $cas->client(CAS_VERSION_2_0,$CFG_GLPI["cas_host"],intval($CFG_GLPI["cas_port"]),
+   phpCAS::client(CAS_VERSION_2_0,$CFG_GLPI["cas_host"],intval($CFG_GLPI["cas_port"]),
                 $CFG_GLPI["cas_uri"],false);
    
-   $cas->logoutWithUrl(strval($CFG_GLPI["cas_logout"]));
+   phpCAS::setServerLogoutURL(strval($CFG_GLPI["cas_logout"]));
+   phpCAS::logout();
 }
 
 $toADD="";
